Exception: MissingInformation
- Inherits:
-
Exception
- Object
- Exception
- MissingInformation
- Defined in:
- lib/processor/processor.rb
Overview
MissingInformation exception is thrown when there is missing information
required to run the processor
Constant Summary collapse
- @@missing_info_messages =
{ :access_key_id => "Must provide an access_key_id", :secret_access_key => "Must provide a secret_access_key" }
Instance Attribute Summary collapse
-
#i ⇒ Object
readonly
Returns the value of attribute i.
Instance Method Summary collapse
-
#initialize(i = nil) ⇒ MissingInformation
constructor
Add the missing information key here.
-
#message ⇒ Object
(also: #to_s)
Takes the missing symbol key and translates it to a message.
Constructor Details
#initialize(i = nil) ⇒ MissingInformation
Add the missing information key here
98 99 100 101 |
# File 'lib/processor/processor.rb', line 98 def initialize(i=nil) super @i = i end |
Instance Attribute Details
#i ⇒ Object (readonly)
Returns the value of attribute i.
96 97 98 |
# File 'lib/processor/processor.rb', line 96 def i @i end |
Instance Method Details
#message ⇒ Object Also known as: to_s
Takes the missing symbol key and translates it to a message
103 104 105 |
# File 'lib/processor/processor.rb', line 103 def "Missing information: #{@@missing_info_messages[@i]}" end |